pydeck Examples
==============

All .ipynb files here can be individually executed and run.

All .py files are meant for individual execution and review, to be hosted on the pydeck website.



## Layers

- ArcLayer
- BitmapLayer
- ColumnLayer
- ContourLayer
- GeoJsonLayer
- HeatmapLayer
- IconLayer
- LineLayer
- PathLayer
- PointCloudLayer
- PolygonLayer
- SolidPolygonLayer
- ScatterplotLayer
- TextLayer
- GPUGridLayeradvanced
- GreatCircleLayer
- CPUGridLayeradvanced
- GridCellLayer
- HexagonLayer
- H3ClusterLayer
- H3HexagonLayer
- GridLayer
- S2Layer
- ScenegraphLayer
- ScreenGridLayer
- SimpleMeshLayer
- TileLayer
- Tile3DLayer
- TripsLayer

## Views

- MapView
- FirstPersonView
- OrthographicView
- OrbitView
- View State Transitions



Data sets used cited below:


US Census bureau-collected at census block level from LEHD Origin-Destination Employment Statistics (LODES) for 2017, published August 28, 2019.
[Source](https://lehd.ces.census.gov/data/)
